Sqreen Python Agent
===================

.. image:: https://img.shields.io/pypi/v/sqreen.svg
   :target: https://pypi.python.org/pypi/sqreen

Sqreen agent to protect Python applications.

Run the tests
-------------

Run unit tests with:

.. code-block:: bash

    $ pip install -r requirements/tests.txt
    $ pip install -e .
    $ pytest

Run the full test suite with:

.. code-block:: bash

    $ pip install -r requirements/dev.txt
    $ pip install -e .
    $ tox

License
-------

Sqreen for Python is free-to-use, proprietary software.
